anova2way.c.bal: Power calculation for two-way balanced analysis of variance contrast test
Description
Performs sample size and power calculations for a test of a contrast
between levels of a factor in a two-way
ANOVA with balanced data (that is, equal sized cells). Can be used to solve for
power, n (sample size per cell), or alpha. For unbalanced data, see
anova2way.c.unbal. For a test of a contrast among cell means, see
anova2way.se.bal.