ci.meandiff: Power calculation for precision analysis (confidence interval) for a difference between two means
Description
Calculates the "power" of a confidence interval for a difference between two means, that is, the probability
of achieving a 100(1 - alpha) percent confidence interval with halfwidth not greater
than a specified value. This function can solve for power, n1, n.ratio or alpha.
A list of the arguments (including the computed one).
Arguments
n1
The sample size for group 1.
n.ratio
The ratio n2/n1 between the sample sizes of two groups; defaults to 1 (equal group sizes).
halfwidth
The desired halfwidth for the difference in means.
sd
The estimated standard deviation; defaults to 1. Equal SDs in each group are assumed.
alpha
The significance level (type 1 error rate); defaults to 0.05.
power
The specified level of power.
cond
Specify using unconditional or conditional probability. Defaults to FALSE.
v
Either TRUE for verbose output or FALSE (default) to output computed argument only.
Details
The unconditional probability is the probability of obtaining the desired precision
(i.e., that the observed halfwidth does not exceed the desired halfwidth)
regardless of whether or not the confidence interval includes the true parameter value.
The conditional probability is the probability of both obtaining the desired precision and having
the interval include the true parameter value.