Learn R Programming

powertools (version 1.0.0)

es.fsq.overall: Cohen f-squared effect size for overall F test in multiple linear regression

Description

Computes the f-squared (f^2) effect size for an overall F test in a multiple linear regression model based on the model R^2 (Rsq). Based on Cohen (1988).

Usage

es.fsq.overall(Rsq = 0.02)

Value

A list of the arguments and the f^2 effect size.

Arguments

Rsq

The squared sample multiple correlation coefficient.

Details

Cohen J (1988) Statistical Power Analysis for the Behavioral Sciences, 2nd edition. Lawrence Erlbaum Associates, Hillsdale, New Jersey

Examples

Run this code
es.fsq.overall(Rsq = 0.02)

Run the code above in your browser using DataLab