irgtt.cont: Power for individually randomized group treatment trial with continuous outcome
Description
Computes power and sample size for an individually randomized group treatment trial with
a continuous outcome, in which after individual randomization, individuals in the
intervention/treatment arm are clustered. Can solve for power, J, m, n, delta or alpha.
Usage
irgtt.cont(
m = NULL,
J = NULL,
n = NULL,
delta = NULL,
sd = 1,
icc = 0,
Theta = 1,
alpha = 0.05,
power = NULL,
sides = 2,
v = FALSE
)
Value
A list of the arguments (including the computed one).
Arguments
m
The number of subjects per cluster in the intervention arm.
J
The total number of clusters in the intervention arm.
n
The total number of participants in the control arm.
delta
The difference between the intervention and control means under the alternative minus the difference under the null hypothesis.
sd
The total standard deviation of the outcome variable in the control arm; defaults to 1.
icc
The intraclass correlation coefficient in the treatment arm; defaults to 0.
Theta
The ratio of the total variance in the intervention and control arms; defaults to 1.
alpha
The significance level (type 1 error rate); defaults to 0.05.
power
The specified level of power.
sides
Either 1 or 2 (default) to specify a one- or two-sided hypothesis test.
v
Either TRUE for verbose output or FALSE (default) to output computed argument only.
Details
Power is solved for using noncentral t or F distribution; other quantities
(for example, sample sizes) are solved
for using normal approximation.