re.clustsize.bin: Relative efficiency of a cluster randomized or multisite trial with binary outcome
with varying cluster sizes
Description
For a binary outcome, computes the relative efficiency (ratio of the variances) of a cluster randomized
or multisite trial with varying cluster (site) sizes to that of a trial with constant cluster sizes,
assuming equal total number of subjects. This approximation may not be valid for all combinations of
parameters, for example when m.sd is large.
Usage
re.clustsize.bin(m, m.sd, pc, pt, sigma.u)
Value
The computed RE.
Arguments
m
The number of subjects per cluster or the mean cluster size (if unequal number of participants per cluster).
m.sd
The standard deviation of cluster sizes (in case of unequal number of participants per cluster).
pc
The probability of the outcome in control clusters.
pt
The probability of the outcome in treatment clusters.
sigma.u
Standard deviation of the cluster random effect.
Details
Candel MJJM and van Breukelen GJP (2010) Sample size adjustments for varying cluster sizes in
cluster randomized trials with binary outcomes analyzed with second-order PQL mixed logistic regression.
Statistics in Medicine 29(14):1488-1501.