re.clustsize.cont: Relative efficiency of a cluster randomized or multisite trial with continuous outcome
with varying cluster sizes
Description
For a continuous outcome, computes the relative efficiency (ratio of the variances) of a cluster randomized
or multisite trial with varying cluster (site) sizes to that of a trial with constant cluster sizes,
assuming equal total number of subjects. This approximation may not be valid for all combinations of
parameters, for example when m.sd is large.
Usage
re.clustsize.cont(m, m.sd, icc)
Value
The computed RE.
Arguments
m
The number of subjects per cluster or the mean cluster size (if unequal number of participants per cluster).
m.sd
The standard deviation of cluster sizes (in case of unequal number of participants per cluster).
icc
The intraclass correlation coefficient. For a multisite trial this is icc1. For a CRT this is the average of the 2 icc's.