powered by
Performs power and sample size calculations for a paired t test. Can solve for power, N, delta or alpha.
ttest.paired( N = NULL, delta = NULL, sd1 = 1, sd2 = NULL, rho = NULL, alpha = 0.05, power = NULL, sides = 2, v = FALSE )
A list of the arguments (including the computed one).
The sample size; if the observations are paired differences, this is the number of pairs.
DeltaA (the true mean difference) - Delta0 (the mean difference under the null).
The pre standard deviation; defaults to 1.
The post standard deviation; defaults to the value of sd1.
The correlation between pre and post measurements on the same individual.
The significance level (type 1 error rate); defaults to 0.05.
The specified level of power.
Either 1 or 2 (default) to specify a one- or two- sided hypothesis test.
Either TRUE for verbose output or FALSE (default) to output computed argument only.
ttest.paired(N = NULL, delta = 4, sd1 = 10, sd2 = 10, rho = 0.4, power = 0.8, sides = 2)
Run the code above in your browser using DataLab