crt.means.r: Correlation between a cluster mean at baseline and follow up
Description
For a cluster randomized trial with a continuous outcome, this function calculates the correlation
between a cluster's mean at baseline and at follow up based on various inputs.
For cross-sectional sampling of subjects,
that is, different subjects are measured at baseline and follow up, specify sac = 0.
Usage
crt.means.r(m, icc, cac, sac)
Value
The computed correlation.
Arguments
m
The number of measurements in each cluster at baseline and follow up.